@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply chromatic and diatonic transposition to notes
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -102,18 +102,18 @@ Music::MelodicDevice::Transposition - Apply chromatic and diatonic transposition
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
   use Music::MelodicDevice::Transposition;
 
-  my @notes = qw(C4 E4 D4 G4 C5);
+  my @notes = qw(C4 E4 D4 G4 C5); # either named notes or midinums
 
   # Chromatic
   my $md = Music::MelodicDevice::Transposition->new;
   my $transposed = $md->transpose(2, \@notes); # [D4, F#4, E4, A4, D5]
-  $transposed = $md->transpose(4, \@notes); # [E4, G#4, F#4, B4, E5]
+  $transposed = $md->transpose(4, \@notes);    # [E4, G#4, F#4, B4, E5]
 
   # Diatonic
   $md = Music::MelodicDevice::Transposition->new(scale_name => 'major');
@@ -123,7 +123,8 @@ version 0.0500
 =head1 DESCRIPTION
 
 C<Music::MelodicDevice::Transposition> applies transposition, both
-chromatic or diatonic, to a series of ISO formatted notes.
+chromatic or diatonic, to a series of ISO  or "midinum" formatted
+notes.
 
 While there are modules on CPAN that do chromatic transposition,
 none appear to apply diatonic transposition to an arbitrary series of
@@ -156,7 +157,7 @@ Default: C<0>
   $md = Music::MelodicDevice::Transposition->new(
     scale_note => $scale_note,
     scale_name => $scale_name,
-    verbose => $verbose,
+    verbose    => $verbose,
   );
 
 Create a new C<Music::MelodicDevice::Transposition> object.
@@ -170,7 +171,7 @@ appropriately based on the number of notes in the chosen scale.
 
 =head1 SEE ALSO
 
-The F<t/01-methods.t> test file
+The F<t/01-methods.t> test and the F<eg/*> example files
 
 L<Data::Dumper::Compact>
 
